pub struct BundleAbility {
pub template: AbilityTemplate,
pub shards_amount: i64,
}Fields
template: AbilityTemplateshards_amount: i64Trait Implementations
Sourceimpl Clone for BundleAbility
impl Clone for BundleAbility
Sourcefn clone(&self) -> BundleAbility
fn clone(&self) -> BundleAbility
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BundleAbility
impl Debug for BundleAbility
Sourceimpl Default for BundleAbility
impl Default for BundleAbility
Sourcefn default() -> BundleAbility
fn default() -> BundleAbility
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BundleAbility
impl<'de> Deserialize<'de> for BundleAbility
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BundleAbility
impl JsonSchema for BundleAbility
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BundleAbility
impl PartialEq for BundleAbility
Sourceimpl Serialize for BundleAbility
impl Serialize for BundleAbility
Sourceimpl Tsify for BundleAbility
impl Tsify for BundleAbility
const DECL: &'static str = "export interface BundleAbility {\n template: AbilityTemplate;\n shards_amount: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for BundleAbility
impl StructuralPartialEq for BundleAbility