pub struct BundleRawStep {
pub item_type: BundleStepType,
pub script: String,
pub has_pop_up: bool,
}Fields
item_type: BundleStepTypescript: Stringhas_pop_up: boolTrait Implementations
Sourceimpl Clone for BundleRawStep
impl Clone for BundleRawStep
Sourcefn clone(&self) -> BundleRawStep
fn clone(&self) -> BundleRawStep
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BundleRawStep
impl Debug for BundleRawStep
Sourceimpl<'de> Deserialize<'de> for BundleRawStep
impl<'de> Deserialize<'de> for BundleRawStep
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BundleRawStep
impl JsonSchema for BundleRawStep
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BundleRawStep
impl PartialEq for BundleRawStep
Sourceimpl Serialize for BundleRawStep
impl Serialize for BundleRawStep
Sourceimpl Tsify for BundleRawStep
impl Tsify for BundleRawStep
const DECL: &'static str = "export interface BundleRawStep {\n item_type: BundleStepType;\n script: string;\n has_pop_up: boolean;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for BundleRawStep
impl StructuralPartialEq for BundleRawStep