pub struct BundleStep {
pub bundle_id: BundleId,
pub element: BundleElement,
pub has_pop_up: bool,
}Fields
bundle_id: BundleIdelement: BundleElementhas_pop_up: boolTrait Implementations
Sourceimpl Clone for BundleStep
impl Clone for BundleStep
Sourcefn clone(&self) -> BundleStep
fn clone(&self) -> BundleStep
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for BundleStep
impl CustomType for BundleStep
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for BundleStep
impl Debug for BundleStep
Sourceimpl Default for BundleStep
impl Default for BundleStep
Sourcefn default() -> BundleStep
fn default() -> BundleStep
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BundleStep
impl<'de> Deserialize<'de> for BundleStep
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BundleStep
impl JsonSchema for BundleStep
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BundleStep
impl PartialEq for BundleStep
Sourceimpl Serialize for BundleStep
impl Serialize for BundleStep
Sourceimpl Tsify for BundleStep
impl Tsify for BundleStep
const DECL: &'static str = "export interface BundleStep {\n bundle_id: BundleId;\n element: BundleElement;\n has_pop_up: boolean;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for BundleStep
impl StructuralPartialEq for BundleStep